@@ -6,5 +6,3 @@ from .filter import filter
 from .plugin import plugin
 from .service import service
 from .util import util
-from .repertory import db
-from .domain import domain
